@@ -13,13 +13,14 @@
 #'
 #' Its main functions are:
 #' \itemize{
+#'   \item [run_app()], running `run_app("intro")` will open an introductory `shiny` app demonstrating radial tours.
 #'   \item [play_manual_tour()], performs a manual tour, returning a `plotly` animate by default.
-#'   \item [play_tour_path()], turns a tour path into an animatation, returning a `plotly` object by default.
+#'   \item [play_tour_path()], turns a tour path into an animation, returning a `plotly` object by default.
 #'   \item [view_basis()], plot a basis set on a reference axis.
-#'   \item [view_manip_space()], plot a manipualation space highlighting the manip var.
+#'   \item [view_manip_space()], plot a manipulation space highlighting the manip var.
 #' }
 #'
-#' GitHub repo: \url{https://github.com/nspyrison/spinifex}
+#' GitHub: \url{https://github.com/nspyrison/spinifex}
 #' @seealso tourr (package)
 #' @name spinifex
 #' @docType package
@@ -28,25 +29,21 @@
 # Manual tour globals:
 globalVariables(c("col",
                   "pch",
-                  "disp_type",
                   "phi_min",
                   "phi_max",
                   "manip_col",
                   "manip_type",
                   "n_slides",
-                  "slide",
-                  "theta")
+                  "theta",
+                  "angle")
 )
 
 # ggplot aes globals:
-globalVariables(c("V1",
-                  "V2",
-                  "x",
+globalVariables(c("x",
                   "y",
                   "z",
                   "xend",
                   "yend",
                   "lab",
-                  "lab_abbr",
                   "slide")
 )
